==> cdk-watchful-0.5.43.tar.gz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### 0.5.43 (2020-11-10)

### 0.5.42 (2020-11-09)

### 0.5.41 (2020-11-08)

### 0.5.40 (2020-11-07)

### 0.5.39 (2020-11-06)

### 0.5.38 (2020-11-04)

### 0.5.37 (2020-11-02)

### 0.5.36 (2020-10-30)

### 0.5.35 (2020-10-29)

### 0.5.34 (2020-10-28)

### 0.5.33 (2020-10-27)

### 0.5.32 (2020-10-26)

### 0.5.31 (2020-10-24)

### 0.5.30 (2020-10-23)

### 0.5.29 (2020-10-22)

### 0.5.28 (2020-10-21)

### 0.5.27 (2020-10-20)

### 0.5.26 (2020-10-18)

### 0.5.25 (2020-10-17)

### 0.5.24 (2020-10-15)

### 0.5.23 (2020-10-14)

### 0.5.22 (2020-10-13)

### 0.5.21 (2020-10-12)

### 0.5.20 (2020-10-09)

### 0.5.19 (2020-10-08)

### 0.5.18 (2020-10-08)

### 0.5.17 (2020-10-07)

### 0.5.16 (2020-10-06)

### 0.5.15 (2020-10-06)

### 0.5.14 (2020-10-05)

### 0.5.13 (2020-10-05)

### 0.5.12 (2020-10-05)

### 0.5.11 (2020-10-04)

### 0.5.10 (2020-10-01)

### 0.5.9 (2020-09-22)

### 0.5.8 (2020-09-14)

### 0.5.7 (2020-09-07)

### 0.5.6 (2020-09-03)

### 0.5.5 (2020-09-02)

### 0.5.4 (2020-08-26)

### [0.5.3](https://github.com/eladb/cdk-watchful/compare/v0.4.6...v0.5.3) (2020-07-28)


### Features

* **cdk:** support for watching ECS Services Fargate & EC2 ([9335c7f](https://github.com/eladb/cdk-watchful/commit/9335c7fa230a4e24acaf5dacc12ef6e59ba603d2))
* add ability to pass in IQueue and ITopic instead of arn ([67248e9](https://github.com/eladb/cdk-watchful/commit/67248e9ed5cf2e54b56d53048e25feb098c732d1))
* **sns:** add ability to pass in an sns topic arn ([35355fa](https://github.com/eladb/cdk-watchful/commit/35355fae7718941c683eef8582a1ce3cc2105cd3))

### [0.5.2](https://github.com/eladb/cdk-watchful/compare/v0.4.6...v0.5.2) (2020-07-23)


### Features

* **cdk:** support for watching RDS Aurora clusters ([483aa9b](https://github.com/eladb/cdk-watchful/commit/483aa9b491f3ea639713e48e92c0302a746ff861))
* **cdk:** support for watching RDS Aurora clusters (update gitignore) ([c7e29da](https://github.com/eladb/cdk-watchful/commit/c7e29dac40bf217e3e5a3bc0d6b7cca237a292ca))
* add ability to pass in IQueue and ITopic instead of arn ([67248e9](https://github.com/eladb/cdk-watchful/commit/67248e9ed5cf2e54b56d53048e25feb098c732d1))
* **sns:** add ability to pass in an sns topic arn ([35355fa](https://github.com/eladb/cdk-watchful/commit/35355fae7718941c683eef8582a1ce3cc2105cd3))

### 0.4.6 (2020-02-24)


### Features

* support for watching API Gateway ([e942e4a](https://github.com/eladb/cdk-watchful/commit/e942e4a65f274c6e0b0d3b21315b6481e5aa5b31))

==> cdk-watchful-0.5.62.tar.gz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### 0.5.62 (2020-12-17)

### 0.5.61 (2020-12-15)

### 0.5.60 (2020-12-12)

### 0.5.59 (2020-12-12)

### 0.5.58 (2020-12-09)

### 0.5.57 (2020-12-09)

### 0.5.56 (2020-12-08)

### 0.5.55 (2020-12-07)

### 0.5.54 (2020-12-06)

### 0.5.53 (2020-12-06)

### 0.5.52 (2020-12-04)

### 0.5.51 (2020-12-03)

### 0.5.50 (2020-12-02)

### 0.5.49 (2020-12-02)

### 0.5.48 (2020-12-02)

### 0.5.47 (2020-12-01)

### 0.5.46 (2020-12-01)

### 0.5.45 (2020-11-12)


### Bug Fixes

* **dynamodb:** add support for pay_per_request tables ([#152](https://github.com/eladb/cdk-watchful/issues/152)) ([1debc6b](https://github.com/eladb/cdk-watchful/commit/1debc6b6e37715ddef582802d7125b30dc8c14d6)), closes [#2](https://github.com/eladb/cdk-watchful/issues/2)

### [0.5.44](https://github.com/eladb/cdk-watchful/compare/v0.5.43...v0.5.44) (2020-11-12)


### Bug Fixes

* add support for pay_per_request tables ([72602f6](https://github.com/eladb/cdk-watchful/commit/72602f65bee1416cfc29fd5195897d96059f1b19))

### 0.5.43 (2020-11-10)

### 0.5.42 (2020-11-09)

### 0.5.41 (2020-11-08)

### 0.5.40 (2020-11-07)

### 0.5.39 (2020-11-06)

### 0.5.38 (2020-11-04)

### 0.5.37 (2020-11-02)

### 0.5.36 (2020-10-30)

### 0.5.35 (2020-10-29)

### 0.5.34 (2020-10-28)

### 0.5.33 (2020-10-27)

### 0.5.32 (2020-10-26)

### 0.5.31 (2020-10-24)

### 0.5.30 (2020-10-23)

### 0.5.29 (2020-10-22)

### 0.5.28 (2020-10-21)

### 0.5.27 (2020-10-20)

### 0.5.26 (2020-10-18)

### 0.5.25 (2020-10-17)

### 0.5.24 (2020-10-15)

### 0.5.23 (2020-10-14)

### 0.5.22 (2020-10-13)

### 0.5.21 (2020-10-12)

### 0.5.20 (2020-10-09)

### 0.5.19 (2020-10-08)

### 0.5.18 (2020-10-08)

### 0.5.17 (2020-10-07)

### 0.5.16 (2020-10-06)

### 0.5.15 (2020-10-06)

### 0.5.14 (2020-10-05)

### 0.5.13 (2020-10-05)

### 0.5.12 (2020-10-05)

### 0.5.11 (2020-10-04)

### 0.5.10 (2020-10-01)

### 0.5.9 (2020-09-22)

### 0.5.8 (2020-09-14)

### 0.5.7 (2020-09-07)

### 0.5.6 (2020-09-03)

### 0.5.5 (2020-09-02)

### 0.5.4 (2020-08-26)

### [0.5.3](https://github.com/eladb/cdk-watchful/compare/v0.4.6...v0.5.3) (2020-07-28)


### Features

* **cdk:** support for watching ECS Services Fargate & EC2 ([9335c7f](https://github.com/eladb/cdk-watchful/commit/9335c7fa230a4e24acaf5dacc12ef6e59ba603d2))
* add ability to pass in IQueue and ITopic instead of arn ([67248e9](https://github.com/eladb/cdk-watchful/commit/67248e9ed5cf2e54b56d53048e25feb098c732d1))
* **sns:** add ability to pass in an sns topic arn ([35355fa](https://github.com/eladb/cdk-watchful/commit/35355fae7718941c683eef8582a1ce3cc2105cd3))

### [0.5.2](https://github.com/eladb/cdk-watchful/compare/v0.4.6...v0.5.2) (2020-07-23)


### Features

* **cdk:** support for watching RDS Aurora clusters ([483aa9b](https://github.com/eladb/cdk-watchful/commit/483aa9b491f3ea639713e48e92c0302a746ff861))
* **cdk:** support for watching RDS Aurora clusters (update gitignore) ([c7e29da](https://github.com/eladb/cdk-watchful/commit/c7e29dac40bf217e3e5a3bc0d6b7cca237a292ca))
* add ability to pass in IQueue and ITopic instead of arn ([67248e9](https://github.com/eladb/cdk-watchful/commit/67248e9ed5cf2e54b56d53048e25feb098c732d1))
* **sns:** add ability to pass in an sns topic arn ([35355fa](https://github.com/eladb/cdk-watchful/commit/35355fae7718941c683eef8582a1ce3cc2105cd3))

### 0.4.6 (2020-02-24)


### Features

* support for watching API Gateway ([e942e4a](https://github.com/eladb/cdk-watchful/commit/e942e4a65f274c6e0b0d3b21315b6481e5aa5b31))
